@@ -1,7 +1,9 @@
 //! Value types accepted by aggregation clauses
 
 // Common parameters
+mod aggregation_name;
 mod rate_mode;
 
 // Public re-exports
+pub use self::aggregation_name::*;
 pub use self::rate_mode::*;
