@@ -96,8 +96,9 @@ impl ShouldSkip for HasParentQuery {
 mod tests {
     use super::*;
 
-    test_serialization! {
-        with_required_fields(
+    #[test]
+    fn serialization() {
+        assert_serialize(
             Query::has_parent("parent", Query::term("tag", "elasticsearch")),
             json!({
                 "has_parent": {
@@ -110,10 +111,10 @@ mod tests {
                         }
                     }
                 }
-            })
+            }),
         );
 
-        with_all_fields(
+        assert_serialize(
             Query::has_parent("parent", Query::term("tag", "elasticsearch"))
                 .boost(2)
                 .name("test")
@@ -134,7 +135,7 @@ mod tests {
                     "boost": 2,
                     "_name": "test"
                 }
-            })
+            }),
         );
     }
 }
